==============
AIOREST Client
==============


.. image:: https://img.shields.io/pypi/v/aiorest_client.svg
        :target: https://pypi.python.org/pypi/aiorest_client

.. image:: https://img.shields.io/travis/klen/aiorest_client.svg
        :target: https://travis-ci.org/klen/aiorest_client

.. image:: https://readthedocs.org/projects/aiorest-client/badge/?version=latest
        :target: https://aiorest-client.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/klen/aiorest_client/shield.svg
     :target: https://pyup.io/repos/github/klen/aiorest_client/
     :alt: Updates



A helper to call REST API from aiohttp


* Free software: MIT license
* Documentation: https://aiorest-client.readthedocs.io.
